(********************************************************************************)
(*  ocamlcore-api: Access to OCamlCore.org services                             *)
(*                                                                              *)
(*  Copyright (C) 2011, OCamlCore SARL                                          *)
(*                                                                              *)
(*  This library is free software; you can redistribute it and/or modify it     *)
(*  under the terms of the GNU Lesser General Public License as published by    *)
(*  the Free Software Foundation; either version 2.1 of the License, or (at     *)
(*  your option) any later version, with the OCaml static compilation           *)
(*  exception.                                                                  *)
(*                                                                              *)
(*  This library is distributed in the hope that it will be useful, but         *)
(*  WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY  *)
(*  or FITNESS FOR A PARTICULAR PURPOSE. See the file COPYING for more          *)
(*  details.                                                                    *)
(*                                                                              *)
(*  You should have received a copy of the GNU Lesser General Public License    *)
(*  along with this library; if not, write to the Free Software Foundation,     *)
(*  Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA               *)
(********************************************************************************)

(** CLI for OCamlCore API
    @author Sylvain Le Gall
  *)

open Lwt

let conf_ini =
  ref OCAContext.default_conf_ini

let stub = 
  ref false

let ctxt () = 
  if !stub then
    let ctxt, stub_id = 
      OCAContext.create_stub ()
    in
      OCAStub.populate stub_id;
      ctxt
  else
    OCAContext.create ~conf_ini:!conf_ini ()

let account_list () = 
  let ctxt = 
    ctxt ()
  in
    Lwt_main.run 
      (OCAAccount.list ~ctxt ()
       >>= 
       Lwt_list.iter_s
         (fun accnt ->
            Lwt_io.printl (OCAAccount.to_string accnt)))

let () = 
  let act = 
    ref 
      (fun () ->
         failwith "No action defined")
  in
    Arg.parse
      [
        "-f",
        Arg.Set_string conf_ini,
        "fn OCamlCore API configuration file.";

        "-s",
        Arg.Set stub,
        " Use stub mode.";
      ]

      (function
         | "account-list" ->
             act := account_list
             
         | str ->
             failwith 
               (Printf.sprintf 
                  "Unknown action '%s'"
                  str))

      "OCamlCore API command line interface, by Sylvain Le Gall\n\
       \n\
       ocamlcore-api [options]* account-list
       \n\
       Options:\n";

    !act ()

