(********************************************************************************)
(*  ocamlcore-api: Access to OCamlCore.org services                             *)
(*                                                                              *)
(*  Copyright (C) 2011, OCamlCore SARL                                          *)
(*                                                                              *)
(*  This library is free software; you can redistribute it and/or modify it     *)
(*  under the terms of the GNU Lesser General Public License as published by    *)
(*  the Free Software Foundation; either version 2.1 of the License, or (at     *)
(*  your option) any later version, with the OCaml static compilation           *)
(*  exception.                                                                  *)
(*                                                                              *)
(*  This library is distributed in the hope that it will be useful, but         *)
(*  WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY  *)
(*  or FITNESS FOR A PARTICULAR PURPOSE. See the file COPYING for more          *)
(*  details.                                                                    *)
(*                                                                              *)
(*  You should have received a copy of the GNU Lesser General Public License    *)
(*  along with this library; if not, write to the Free Software Foundation,     *)
(*  Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA               *)
(********************************************************************************)

(** Web services for account 
    @author Sylvain Le Gall
  *)

open XHTML.M
open Eliom_predefmod.Xhtml
open Lwt
open OCAAccount
open Common
open Context
open Eliom_services
open Eliom_parameters

let get ~ctxt ?sess sp = 
  begin
    match sess with 
      | Some sess_opt ->
          return sess_opt
      | None ->
          Session.get ~ctxt sp 
  end
  >>= function
    | Some sess ->
        OCAAccount.of_id 
          ~ctxt:ctxt.web_ctxt 
          sess.OCASession.sess_user_id
        >>= fun accnt ->
        return (Some accnt)

    | None ->
        return None

let user_settings_box ~ctxt ?sess ?accnt sp = 
  begin
    match accnt with 
      | Some accnt_opt ->
          return accnt_opt
      | None ->
          get ~ctxt ?sess sp 
  end
  >>= fun accnt_opt ->
  return 
    (div 
       (match accnt_opt with 
          | Some accnt ->
              [
                table
                  (tr
                     (td [pcdata (s_ "Real name")])
                     [td [pcdata accnt.accnt_real_name]])
                  [tr
                     (td [pcdata (s_ "Time zone")])
                     [td [pcdata (OCATimezone.to_string accnt.accnt_tz)]];
                   tr
                     (td [pcdata (s_ "Language")])
                     [td [pcdata accnt.accnt_lang]];
                   tr
                     (td [pcdata (s_ "Unix name")])
                     [td [pcdata accnt.accnt_unix_name]];
                  ];

                p [XHTML.M.a 
                     ~a:[a_href (ctxt.web_manage_account sp)]
                     [pcdata (s_ "Edit settings on the OCaml Forge")]];
              ]
          | None ->
              [em [pcdata (s_ "No settings for anonymous user.")]]))

let my_account ~ctxt sp = 
  ctxt.web_my_account_ext sp 

let new_account ~ctxt sp =
  ctxt.web_new_account_ext sp 

let manage_account ~ctxt sp =
  ctxt.web_manage_account_ext sp 

let lost_passwd ~ctxt sp =
  ctxt.web_lost_passwd sp

