(********************************************************************************)
(*  ocamlcore-api: Access to OCamlCore.org services                             *)
(*                                                                              *)
(*  Copyright (C) 2011, OCamlCore SARL                                          *)
(*                                                                              *)
(*  This library is free software; you can redistribute it and/or modify it     *)
(*  under the terms of the GNU Lesser General Public License as published by    *)
(*  the Free Software Foundation; either version 2.1 of the License, or (at     *)
(*  your option) any later version, with the OCaml static compilation           *)
(*  exception.                                                                  *)
(*                                                                              *)
(*  This library is distributed in the hope that it will be useful, but         *)
(*  WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY  *)
(*  or FITNESS FOR A PARTICULAR PURPOSE. See the file COPYING for more          *)
(*  details.                                                                    *)
(*                                                                              *)
(*  You should have received a copy of the GNU Lesser General Public License    *)
(*  along with this library; if not, write to the Free Software Foundation,     *)
(*  Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA               *)
(********************************************************************************)


(** Common functions 
    @author Sylvain Le Gall
  *)

open Eliom_sessions
open XHTML.M

let s_ s = s

let self_uri sp =
  let proto =
    if get_ssl ~sp then
      "https"
    else
      "http"
  in
  let port =
    match get_server_port ~sp with 
      | 80 -> ""
      | n -> ":"^(string_of_int n)
  in
  let full_url = 
    get_full_url ~sp
  in
  let full_url =
    if BatString.starts_with full_url "/" then
      full_url
    else
      "/"^full_url
  in
    Printf.sprintf 
      "%s://%s%s%s"
      proto
      (get_hostname ~sp)
      port
      full_url

let uri_template ?(extra=[]) ?uri_param redirect tmpl sp = 
  (* Compute the current URI *)
  let uri_param = 
    Netencoding.Url.encode 
      (redirect sp 
         (match uri_param with 
            | Some uri -> string_of_uri uri 
            | None -> self_uri sp))
  in

  (* Do the replacement in the URI template *)
  let str_uri = 
    let buf = 
      Buffer.create ((String.length tmpl) + 
                     (String.length uri_param))
    in
      Buffer.add_substitute
        buf
        (function
           | "redirect" ->
               uri_param
           | e ->
               try 
                 List.assoc e extra
               with Not_found ->
                 "$("^e^")")
        tmpl;
      Buffer.contents buf
  in
    uri_of_string str_uri

