type t 

open Eliom_services
open Eliom_parameters
open Eliom_sessions
open XHTML.M

type ('a, 'b) service = 
    ('a, unit, get_service_kind, [`WithoutSuffix], 'b, unit, registrable) 
      Eliom_services.service

val create:
  ?my_account:(string option, 'a) service ->
  ?new_account:(string option, 'b) service ->
  ?manage_account:(string option, 'c) service ->
  ?stub:bool ->
  ?conf_ini:string ->
  ?ignore_ip:bool ->
  ?redirect:(server_params -> string -> string) ->
  ?base_path:(string list) ->
  unit -> t

val create_from_config:
  ?my_account:(string option, 'a) service -> 
  ?new_account:(string option, 'b) service -> 
  ?manage_account:(string option, 'c) service ->
  unit -> t

val to_oca_context: t -> OCAContext.t

module Session:
sig
  val get: ctxt:t -> server_params -> OCASession.t option Lwt.t

  val action_box:
    ctxt:t ->
    ?sess:OCASession.t option ->
    server_params -> [> `Div ] XHTML.M.elt Lwt.t

  val login_get: ctxt:t -> server_params -> string -> string -> uri 

  val logout_get: ctxt:t -> server_params -> uri 

  val with_login: ctxt:t -> server_params -> uri -> 
    [< `PCDATA | XHTML.M.inline_sans_a_mix] XHTML.M.elt list -> [> `A] XHTML.M.elt
end

module Account:
sig
  val get:
    ctxt:t ->
    ?sess:OCASession.t option ->
    server_params -> OCAAccount.t option Lwt.t

  val user_settings_box:
    ctxt:t ->
    ?sess:OCASession.t option ->
    ?accnt:OCAAccount.t option ->
    server_params -> [> `Div ] XHTML.M.elt Lwt.t

  val my_account: ctxt:t -> server_params -> uri

  val new_account: ctxt:t -> server_params -> uri

  val manage_account: ctxt:t -> server_params -> uri

  val lost_passwd: ctxt:t -> server_params -> uri
end

module Template:
sig
  val make_page:
    ctxt:t ->
    website_title:string ->
    page_title:string ->
    [< `Link | `Meta | `Object | `Script | `Style > `Style ] XHTML.M.elt list ->
    flow XHTML.M.elt list ->
    html
end

module Redirect:
sig
  (* Take into account URI rewriting due to rev proxy *)
  val rewrite: ctxt:t -> server_params -> uri -> uri 
end

