(********************************************************************************)
(*  ocamlcore-api: Access to OCamlCore.org services                             *)
(*                                                                              *)
(*  Copyright (C) 2011, OCamlCore SARL                                          *)
(*                                                                              *)
(*  This library is free software; you can redistribute it and/or modify it     *)
(*  under the terms of the GNU Lesser General Public License as published by    *)
(*  the Free Software Foundation; either version 2.1 of the License, or (at     *)
(*  your option) any later version, with the OCaml static compilation           *)
(*  exception.                                                                  *)
(*                                                                              *)
(*  This library is distributed in the hope that it will be useful, but         *)
(*  WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY  *)
(*  or FITNESS FOR A PARTICULAR PURPOSE. See the file COPYING for more          *)
(*  details.                                                                    *)
(*                                                                              *)
(*  You should have received a copy of the GNU Lesser General Public License    *)
(*  along with this library; if not, write to the Free Software Foundation,     *)
(*  Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA               *)
(********************************************************************************)

(** Session functions that only depends on ocamlcore-api (no Context
    dependencies)
    @author Sylvain Le Gall
  *)

open Eliom_sessions
open OCASession
open Lwt

let get ~ctxt ignore_ip sp = 
  try 
    let session_cookie = 
      (Ocsigen_lib.String_Table.find 
         cookie_name
         (get_cookies sp))
    in
    let sess = 
      of_cookie session_cookie
    in
    let ip =
      if ignore_ip then 
        None
      else
        Some (get_remote_inet_addr ~sp)
    in
      check 
        ~ctxt
        ~user_agent:(get_user_agent ~sp)
        ?ip
        sess
      >>= function
        | true ->
            return (Some sess)
        | false ->
            return None

  with Not_found ->
    return None
